// 引入所需模块
const express = require('express');
const bodyParser = require('body-parser');
const pgp = require('pg-promise')();
const db = pgp('postgresql://web3:666@web2023.fmode.cn:25432/dev');

// 创建Express应用
const app = express();
app.use(bodyParser.json());

// 会员账号注册接口
/**
 * @api {post} /register 会员账号注册接口
 * @apiName Register
 * @apiGroup Member
 *
 * @apiParam {String} mobile 手机号
 * @apiParam {String} code 验证码
 * @apiParam {String} inviteId 邀请人ID
 *
 * @apiSuccess {Object} data 注册结果信息
 */
 app.post('/register', async (req, res) => {
    const { mobile, code, inviteId } = req.body;

    // 验证请求参数
    if (!mobile || !code || !inviteId) {
        return res.status(400).json({ error: '缺少必要参数' });
    }

    try {
        // 查询邀请人信息
        const inviteMember = await db.oneOrNone('SELECT * FROM "Member" WHERE "objectId" = $1', inviteId);

        if (!inviteMember) {
            return res.status(400).json({ error: '邀请人不存在' });
        }

        // 插入新会员信息
        const newMember = await db.one(
            'INSERT INTO "Member" ("objectId", "mobile", "registerDate", "invite", "invitePath", "inviteDate") VALUES ($1,$2,$3,$4,$5,$6) RETURNING *',
            [mobile, mobile, new Date(), inviteId, null, null]
        );

        res.json({ data: newMember });
    } catch (error) {
        console.error('注册失败:', error);
        res.status(500).json({ error: '注册失败' });
    }
});

// 建立邀请关系接口
/**
 * @api {get} /invite 建立邀请关系接口
 * @apiName Invite
 * @apiGroup Invite
 *
 * @apiParam {String} inviterId 邀请人ID
 * @apiParam {String} inviteeId 被邀请人ID
 *
 * @apiSuccess {Object} data 建立邀请关系结果信息
 */
app.get('/invite', async (req, res) => {
    // 实现建立邀请关系逻辑
});

// 邀请数据统计接口
/**
 * @api {get} /stats 邀请数据统计接口
 * @apiName Stats
 * @apiGroup Invite
 *
 * @apiParam {String} userId 当前用户ID
 *
 * @apiSuccess {Object} data 统计数据
 */
app.get('/stats', async (req, res) => {
    // 实现统计数据逻辑
});

// 邀请用户列表接口
/**
 * @api {get} /userlist 邀请用户列表接口
 * @apiName UserList
 * @apiGroup Invite
 *
 * @apiParam {String} userId 当前用户ID
 *
 * @apiSuccess {Object} data 用户列表信息
 */
app.get('/userlist', async (req, res) => {
    // 实现用户列表逻辑
});

// 启动Express服务器
const PORT = 3000;
app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});